@@ -52,13 +52,22 @@ has 'dependency_filter' => (
     }
 );
 
+has 'confliction_checker' => (
+    is      => 'rw',
+    default => sub {
+        CPAN::Packager::ConflictionChecker->new;
+    }
+);
+
 sub analyze_dependencies {
     my ( $self, $module, $config ) = @_;
     return $module
         if $config->{modules}->{$module}
             && $config->{modules}->{$module}->{build_status};
 
-# try to download unresolved name because resolver sometimes return wrong name.
+    return $module unless $self->_is_needed_to_analyze_dependencies($module);
+
+    # try to download unresolved name because resolver sometimes return wrong name.
     my $module_info = $self->download_module( $module, $config );
 
     my $resolved_module = $module_info->{dist_name};
@@ -179,7 +188,7 @@ sub download_module {
 sub _is_needed_to_analyze_dependencies {
     my ( $self, $resolved_module, $config ) = @_;
     return 0 if $self->is_added($resolved_module);
-    return 0 if $self->is_core($resolved_module);
+    return 0 if $self->is_non_dualife_core_module($resolved_module);
     return 0 if $resolved_module eq 'perl';
     return 0 if $resolved_module eq 'PerlInterp';
     return 0 if $config->{modules}->{$resolved_module}->{skip_build};
@@ -201,7 +210,7 @@ sub is_added {
     exists $self->modules->{$module};
 }
 
-sub is_core {
+sub is_non_dualife_core_module {
     my ( $self, $module ) = @_;
     return 1 if $module eq 'perl';
 
@@ -220,11 +229,8 @@ sub is_core {
 }
 
 sub is_dual_lived_module {
-    my ( $self, $module ) = @_;
-    my $conflict_checker = CPAN::Packager::ConflictionChecker->new(
-        downloader => $self->downloader );
-    if ( $conflict_checker->is_dual_lived_module($module) ) {
-        $conflict_checker->check_conflict($module);
+    my ( $self, $module ) = @_; 
+    if ( $self->confliction_checker->is_dual_lived_module($module) ) {
         return 1;
     }
     else {
@@ -253,7 +259,7 @@ sub get_dependencies {
     };
 
     return grep { !$self->is_added($_) }
-        grep    { !$self->is_core($_) } uniq(
+        grep    { !$self->is_non_dualife_core_module($_) } uniq(
         keys %{ $deps->requires || {} },
         keys %{ $deps->build_requires || {} }
         );
